# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/mysql/v1alpha/database.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/mysql/v1alpha/database.proto',
  package='yandex.cloud.mdb.mysql.v1alpha',
  syntax='proto3',
  serialized_options=b'\n\"yandex.cloud.api.mdb.mysql.v1alphaZHgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mysql/v1alpha;mysql',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-yandex/cloud/mdb/mysql/v1alpha/database.proto\x12\x1eyandex.cloud.mdb.mysql.v1alpha\x1a\x1dyandex/cloud/validation.proto\",\n\x08\x44\x61tabase\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\"<\n\x0c\x44\x61tabaseSpec\x12,\n\x04name\x18\x01 \x01(\tB\x1e\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*Bn\n\"yandex.cloud.api.mdb.mysql.v1alphaZHgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mysql/v1alpha;mysqlb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_DATABASE = _descriptor.Descriptor(
  name='Database',
  full_name='yandex.cloud.mdb.mysql.v1alpha.Database',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.mysql.v1alpha.Database.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.mysql.v1alpha.Database.cluster_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=112,
  serialized_end=156,
)


_DATABASESPEC = _descriptor.Descriptor(
  name='DatabaseSpec',
  full_name='yandex.cloud.mdb.mysql.v1alpha.DatabaseSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.mysql.v1alpha.DatabaseSpec.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=63\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=158,
  serialized_end=218,
)

DESCRIPTOR.message_types_by_name['Database'] = _DATABASE
DESCRIPTOR.message_types_by_name['DatabaseSpec'] = _DATABASESPEC
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Database = _reflection.GeneratedProtocolMessageType('Database', (_message.Message,), {
  'DESCRIPTOR' : _DATABASE,
  '__module__' : 'yandex.cloud.mdb.mysql.v1alpha.database_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mysql.v1alpha.Database)
  })
_sym_db.RegisterMessage(Database)

DatabaseSpec = _reflection.GeneratedProtocolMessageType('DatabaseSpec', (_message.Message,), {
  'DESCRIPTOR' : _DATABASESPEC,
  '__module__' : 'yandex.cloud.mdb.mysql.v1alpha.database_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mysql.v1alpha.DatabaseSpec)
  })
_sym_db.RegisterMessage(DatabaseSpec)


DESCRIPTOR._options = None
_DATABASESPEC.fields_by_name['name']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/organizationmanager/v1/saml/federation_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.organizationmanager.v1 import user_account_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_user__account__pb2
from yandex.cloud.organizationmanager.v1.saml import federation_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/organizationmanager/v1/saml/federation_service.proto',
  package='yandex.cloud.organizationmanager.v1.saml',
  syntax='proto3',
  serialized_options=b'\n,yandex.cloud.api.organizationmanager.v1.samlZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/saml;saml',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nAyandex/cloud/organizationmanager/v1/saml/federation_service.proto\x12(yandex.cloud.organizationmanager.v1.saml\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a\x36yandex/cloud/organizationmanager/v1/user_account.proto\x1a\x39yandex/cloud/organizationmanager/v1/saml/federation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"7\n\x14GetFederationRequest\x12\x1f\n\rfederation_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"\x98\x01\n\x16ListFederationsRequest\x12%\n\x0forganization_id\x18\x06 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x03 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1c\n\npage_token\x18\x04 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1a\n\x06\x66ilter\x18\x05 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"}\n\x17ListFederationsResponse\x12I\n\x0b\x66\x65\x64\x65rations\x18\x01 \x03(\x0b\x32\x34.yandex.cloud.organizationmanager.v1.saml.Federation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xd6\x05\n\x17\x43reateFederationRequest\x12!\n\x0forganization_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x31\n\x04name\x18\x02 \x01(\tB#\xf2\xc7\x31\x1f[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12>\n\x0e\x63ookie_max_age\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0b\xfa\xc7\x31\x07\x31\x30m-12h\x12$\n\x1c\x61uto_create_account_on_login\x18\x05 \x01(\x08\x12\x1e\n\x06issuer\x18\x06 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=8000\x12J\n\x0bsso_binding\x18\x07 \x01(\x0e\x32\x35.yandex.cloud.organizationmanager.v1.saml.BindingType\x12\x1f\n\x07sso_url\x18\x08 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=8000\x12_\n\x11security_settings\x18\t \x01(\x0b\x32\x44.yandex.cloud.organizationmanager.v1.saml.FederationSecuritySettings\x12!\n\x19\x63\x61se_insensitive_name_ids\x18\n \x01(\x08\x12\x9e\x01\n\x06labels\x18\x0b \x03(\x0b\x32M.yandex.cloud.organizationmanager.v1.saml.CreateFederationRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"1\n\x18\x43reateFederationMetadata\x12\x15\n\rfederation_id\x18\x01 \x01(\t\"\x86\x06\n\x17UpdateFederationRequest\x12\x1f\n\rfederation_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12>\n\x0e\x63ookie_max_age\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0b\xfa\xc7\x31\x07\x31\x30m-12h\x12$\n\x1c\x61uto_create_account_on_login\x18\x06 \x01(\x08\x12\x1e\n\x06issuer\x18\x07 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=8000\x12J\n\x0bsso_binding\x18\x08 \x01(\x0e\x32\x35.yandex.cloud.organizationmanager.v1.saml.BindingType\x12\x1f\n\x07sso_url\x18\t \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=8000\x12_\n\x11security_settings\x18\n \x01(\x0b\x32\x44.yandex.cloud.organizationmanager.v1.saml.FederationSecuritySettings\x12!\n\x19\x63\x61se_insensitive_name_ids\x18\x0c \x01(\x08\x12\x9e\x01\n\x06labels\x18\r \x03(\x0b\x32M.yandex.cloud.organizationmanager.v1.saml.UpdateFederationRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"1\n\x18UpdateFederationMetadata\x12\x15\n\rfederation_id\x18\x01 \x01(\t\":\n\x17\x44\x65leteFederationRequest\x12\x1f\n\rfederation_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"1\n\x18\x44\x65leteFederationMetadata\x12\x15\n\rfederation_id\x18\x01 \x01(\t\"`\n\x1f\x41\x64\x64\x46\x65\x64\x65ratedUserAccountsRequest\x12\x1f\n\rfederation_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1c\n\x08name_ids\x18\x02 \x03(\tB\n\x8a\xc8\x31\x06<=1000\"9\n AddFederatedUserAccountsMetadata\x12\x15\n\rfederation_id\x18\x01 \x01(\t\"k\n AddFederatedUserAccountsResponse\x12G\n\ruser_accounts\x18\x01 \x03(\x0b\x32\x30.yandex.cloud.organizationmanager.v1.UserAccount\"\x85\x01\n ListFederatedUserAccountsRequest\x12#\n\rfederation_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\x85\x01\n!ListFederatedUserAccountsResponse\x12G\n\ruser_accounts\x18\x01 \x03(\x0b\x32\x30.yandex.cloud.organizationmanager.v1.UserAccount\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x80\x01\n\x1fListFederationOperationsRequest\x12\x1f\n\rfederation_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"r\n ListFederationOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xcb\x0e\n\x11\x46\x65\x64\x65rationService\x12\xbe\x01\n\x03Get\x12>.yandex.cloud.organizationmanager.v1.saml.GetFederationRequest\x1a\x34.yandex.cloud.organizationmanager.v1.saml.Federation\"A\x82\xd3\xe4\x93\x02;\x12\x39/organization-manager/v1/saml/federations/{federation_id}\x12\xbe\x01\n\x04List\x12@.yandex.cloud.organizationmanager.v1.saml.ListFederationsRequest\x1a\x41.yandex.cloud.organizationmanager.v1.saml.ListFederationsResponse\"1\x82\xd3\xe4\x93\x02+\x12)/organization-manager/v1/saml/federations\x12\xce\x01\n\x06\x43reate\x12\x41.yandex.cloud.organizationmanager.v1.saml.CreateFederationRequest\x1a!.yandex.cloud.operation.Operation\"^\x82\xd3\xe4\x93\x02.\")/organization-manager/v1/saml/federations:\x01*\xb2\xd2*&\n\x18\x43reateFederationMetadata\x12\nFederation\x12\xde\x01\n\x06Update\x12\x41.yandex.cloud.organizationmanager.v1.saml.UpdateFederationRequest\x1a!.yandex.cloud.operation.Operation\"n\x82\xd3\xe4\x93\x02>29/organization-manager/v1/saml/federations/{federation_id}:\x01*\xb2\xd2*&\n\x18UpdateFederationMetadata\x12\nFederation\x12\xe6\x01\n\x06\x44\x65lete\x12\x41.yandex.cloud.organizationmanager.v1.saml.DeleteFederationRequest\x1a!.yandex.cloud.operation.Operation\"v\x82\xd3\xe4\x93\x02;*9/organization-manager/v1/saml/federations/{federation_id}\xb2\xd2*1\n\x18\x44\x65leteFederationMetadata\x12\x15google.protobuf.Empty\x12\x9e\x02\n\x0f\x41\x64\x64UserAccounts\x12I.yandex.cloud.organizationmanager.v1.saml.AddFederatedUserAccountsRequest\x1a!.yandex.cloud.operation.Operation\"\x9c\x01\x82\xd3\xe4\x93\x02N\"I/organization-manager/v1/saml/federations/{federation_id}:addUserAccounts:\x01*\xb2\xd2*D\n AddFederatedUserAccountsMetadata\x12 AddFederatedUserAccountsResponse\x12\xff\x01\n\x10ListUserAccounts\x12J.yandex.cloud.organizationmanager.v1.saml.ListFederatedUserAccountsRequest\x1aK.yandex.cloud.organizationmanager.v1.saml.ListFederatedUserAccountsResponse\"R\x82\xd3\xe4\x93\x02L\x12J/organization-manager/v1/saml/federations/{federation_id}:listUserAccounts\x12\xf5\x01\n\x0eListOperations\x12I.yandex.cloud.organizationmanager.v1.saml.ListFederationOperationsRequest\x1aJ.yandex.cloud.organizationmanager.v1.saml.ListFederationOperationsResponse\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/organization-manager/v1/saml/federations/{federation_id}/operationsB\x81\x01\n,yandex.cloud.api.organizationmanager.v1.samlZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/saml;samlb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_user__account__pb2.DESCRIPTOR,yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETFEDERATIONREQUEST = _descriptor.Descriptor(
  name='GetFederationRequest',
  full_name='yandex.cloud.organizationmanager.v1.saml.GetFederationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='federation_id', full_name='yandex.cloud.organizationmanager.v1.saml.GetFederationRequest.federation_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=427,
  serialized_end=482,
)


_LISTFEDERATIONSREQUEST = _descriptor.Descriptor(
  name='ListFederationsRequest',
  full_name='yandex.cloud.organizationmanager.v1.saml.ListFederationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='organization_id', full_name='yandex.cloud.organizationmanager.v1.saml.ListFederationsRequest.organization_id', index=0,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.organizationmanager.v1.saml.ListFederationsRequest.page_size', index=1,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.organizationmanager.v1.saml.ListFederationsRequest.page_token', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.organizationmanager.v1.saml.ListFederationsRequest.filter', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=485,
  serialized_end=637,
)


_LISTFEDERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListFederationsResponse',
  full_name='yandex.cloud.organizationmanager.v1.saml.ListFederationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='federations', full_name='yandex.cloud.organizationmanager.v1.saml.ListFederationsResponse.federations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.organizationmanager.v1.saml.ListFederationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=639,
  serialized_end=764,
)


_CREATEFEDERATIONREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.organizationmanager.v1.saml.CreateFederationRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.organizationmanager.v1.saml.CreateFederationRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.organizationmanager.v1.saml.CreateFederationRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1448,
  serialized_end=1493,
)

_CREATEFEDERATIONREQUEST = _descriptor.Descriptor(
  name='CreateFederationRequest',
  full_name='yandex.cloud.organizationmanager.v1.saml.CreateFederationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='organization_id', full_name='yandex.cloud.organizationmanager.v1.saml.CreateFederationRequest.organization_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.organizationmanager.v1.saml.CreateFederationRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\037[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.organizationmanager.v1.saml.CreateFederationRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cookie_max_age', full_name='yandex.cloud.organizationmanager.v1.saml.CreateFederationRequest.cookie_max_age', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\00710m-12h', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_create_account_on_login', full_name='yandex.cloud.organizationmanager.v1.saml.CreateFederationRequest.auto_create_account_on_login', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issuer', full_name='yandex.cloud.organizationmanager.v1.saml.CreateFederationRequest.issuer', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\006<=8000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sso_binding', full_name='yandex.cloud.organizationmanager.v1.saml.CreateFederationRequest.sso_binding', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sso_url', full_name='yandex.cloud.organizationmanager.v1.saml.CreateFederationRequest.sso_url', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\006<=8000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_settings', full_name='yandex.cloud.organizationmanager.v1.saml.CreateFederationRequest.security_settings', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='case_insensitive_name_ids', full_name='yandex.cloud.organizationmanager.v1.saml.CreateFederationRequest.case_insensitive_name_ids', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.organizationmanager.v1.saml.CreateFederationRequest.labels', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATEFEDERATIONREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=767,
  serialized_end=1493,
)


_CREATEFEDERATIONMETADATA = _descriptor.Descriptor(
  name='CreateFederationMetadata',
  full_name='yandex.cloud.organizationmanager.v1.saml.CreateFederationMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='federation_id', full_name='yandex.cloud.organizationmanager.v1.saml.CreateFederationMetadata.federation_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1495,
  serialized_end=1544,
)


_UPDATEFEDERATIONREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.organizationmanager.v1.saml.UpdateFederationRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.organizationmanager.v1.saml.UpdateFederationRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.organizationmanager.v1.saml.UpdateFederationRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1448,
  serialized_end=1493,
)

_UPDATEFEDERATIONREQUEST = _descriptor.Descriptor(
  name='UpdateFederationRequest',
  full_name='yandex.cloud.organizationmanager.v1.saml.UpdateFederationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='federation_id', full_name='yandex.cloud.organizationmanager.v1.saml.UpdateFederationRequest.federation_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.organizationmanager.v1.saml.UpdateFederationRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.organizationmanager.v1.saml.UpdateFederationRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.organizationmanager.v1.saml.UpdateFederationRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cookie_max_age', full_name='yandex.cloud.organizationmanager.v1.saml.UpdateFederationRequest.cookie_max_age', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\00710m-12h', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_create_account_on_login', full_name='yandex.cloud.organizationmanager.v1.saml.UpdateFederationRequest.auto_create_account_on_login', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issuer', full_name='yandex.cloud.organizationmanager.v1.saml.UpdateFederationRequest.issuer', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\006<=8000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sso_binding', full_name='yandex.cloud.organizationmanager.v1.saml.UpdateFederationRequest.sso_binding', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sso_url', full_name='yandex.cloud.organizationmanager.v1.saml.UpdateFederationRequest.sso_url', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\006<=8000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_settings', full_name='yandex.cloud.organizationmanager.v1.saml.UpdateFederationRequest.security_settings', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='case_insensitive_name_ids', full_name='yandex.cloud.organizationmanager.v1.saml.UpdateFederationRequest.case_insensitive_name_ids', index=10,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.organizationmanager.v1.saml.UpdateFederationRequest.labels', index=11,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATEFEDERATIONREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1547,
  serialized_end=2321,
)


_UPDATEFEDERATIONMETADATA = _descriptor.Descriptor(
  name='UpdateFederationMetadata',
  full_name='yandex.cloud.organizationmanager.v1.saml.UpdateFederationMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='federation_id', full_name='yandex.cloud.organizationmanager.v1.saml.UpdateFederationMetadata.federation_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2323,
  serialized_end=2372,
)


_DELETEFEDERATIONREQUEST = _descriptor.Descriptor(
  name='DeleteFederationRequest',
  full_name='yandex.cloud.organizationmanager.v1.saml.DeleteFederationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='federation_id', full_name='yandex.cloud.organizationmanager.v1.saml.DeleteFederationRequest.federation_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2374,
  serialized_end=2432,
)


_DELETEFEDERATIONMETADATA = _descriptor.Descriptor(
  name='DeleteFederationMetadata',
  full_name='yandex.cloud.organizationmanager.v1.saml.DeleteFederationMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='federation_id', full_name='yandex.cloud.organizationmanager.v1.saml.DeleteFederationMetadata.federation_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2434,
  serialized_end=2483,
)


_ADDFEDERATEDUSERACCOUNTSREQUEST = _descriptor.Descriptor(
  name='AddFederatedUserAccountsRequest',
  full_name='yandex.cloud.organizationmanager.v1.saml.AddFederatedUserAccountsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='federation_id', full_name='yandex.cloud.organizationmanager.v1.saml.AddFederatedUserAccountsRequest.federation_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name_ids', full_name='yandex.cloud.organizationmanager.v1.saml.AddFederatedUserAccountsRequest.name_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2485,
  serialized_end=2581,
)


_ADDFEDERATEDUSERACCOUNTSMETADATA = _descriptor.Descriptor(
  name='AddFederatedUserAccountsMetadata',
  full_name='yandex.cloud.organizationmanager.v1.saml.AddFederatedUserAccountsMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='federation_id', full_name='yandex.cloud.organizationmanager.v1.saml.AddFederatedUserAccountsMetadata.federation_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2583,
  serialized_end=2640,
)


_ADDFEDERATEDUSERACCOUNTSRESPONSE = _descriptor.Descriptor(
  name='AddFederatedUserAccountsResponse',
  full_name='yandex.cloud.organizationmanager.v1.saml.AddFederatedUserAccountsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_accounts', full_name='yandex.cloud.organizationmanager.v1.saml.AddFederatedUserAccountsResponse.user_accounts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2642,
  serialized_end=2749,
)


_LISTFEDERATEDUSERACCOUNTSREQUEST = _descriptor.Descriptor(
  name='ListFederatedUserAccountsRequest',
  full_name='yandex.cloud.organizationmanager.v1.saml.ListFederatedUserAccountsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='federation_id', full_name='yandex.cloud.organizationmanager.v1.saml.ListFederatedUserAccountsRequest.federation_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.organizationmanager.v1.saml.ListFederatedUserAccountsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.organizationmanager.v1.saml.ListFederatedUserAccountsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2752,
  serialized_end=2885,
)


_LISTFEDERATEDUSERACCOUNTSRESPONSE = _descriptor.Descriptor(
  name='ListFederatedUserAccountsResponse',
  full_name='yandex.cloud.organizationmanager.v1.saml.ListFederatedUserAccountsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_accounts', full_name='yandex.cloud.organizationmanager.v1.saml.ListFederatedUserAccountsResponse.user_accounts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.organizationmanager.v1.saml.ListFederatedUserAccountsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2888,
  serialized_end=3021,
)


_LISTFEDERATIONOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListFederationOperationsRequest',
  full_name='yandex.cloud.organizationmanager.v1.saml.ListFederationOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='federation_id', full_name='yandex.cloud.organizationmanager.v1.saml.ListFederationOperationsRequest.federation_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.organizationmanager.v1.saml.ListFederationOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.organizationmanager.v1.saml.ListFederationOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3024,
  serialized_end=3152,
)


_LISTFEDERATIONOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListFederationOperationsResponse',
  full_name='yandex.cloud.organizationmanager.v1.saml.ListFederationOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.organizationmanager.v1.saml.ListFederationOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.organizationmanager.v1.saml.ListFederationOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3154,
  serialized_end=3268,
)

_LISTFEDERATIONSRESPONSE.fields_by_name['federations'].message_type = yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__pb2._FEDERATION
_CREATEFEDERATIONREQUEST_LABELSENTRY.containing_type = _CREATEFEDERATIONREQUEST
_CREATEFEDERATIONREQUEST.fields_by_name['cookie_max_age'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_CREATEFEDERATIONREQUEST.fields_by_name['sso_binding'].enum_type = yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__pb2._BINDINGTYPE
_CREATEFEDERATIONREQUEST.fields_by_name['security_settings'].message_type = yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__pb2._FEDERATIONSECURITYSETTINGS
_CREATEFEDERATIONREQUEST.fields_by_name['labels'].message_type = _CREATEFEDERATIONREQUEST_LABELSENTRY
_UPDATEFEDERATIONREQUEST_LABELSENTRY.containing_type = _UPDATEFEDERATIONREQUEST
_UPDATEFEDERATIONREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATEFEDERATIONREQUEST.fields_by_name['cookie_max_age'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_UPDATEFEDERATIONREQUEST.fields_by_name['sso_binding'].enum_type = yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__pb2._BINDINGTYPE
_UPDATEFEDERATIONREQUEST.fields_by_name['security_settings'].message_type = yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__pb2._FEDERATIONSECURITYSETTINGS
_UPDATEFEDERATIONREQUEST.fields_by_name['labels'].message_type = _UPDATEFEDERATIONREQUEST_LABELSENTRY
_ADDFEDERATEDUSERACCOUNTSRESPONSE.fields_by_name['user_accounts'].message_type = yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_user__account__pb2._USERACCOUNT
_LISTFEDERATEDUSERACCOUNTSRESPONSE.fields_by_name['user_accounts'].message_type = yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_user__account__pb2._USERACCOUNT
_LISTFEDERATIONOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['GetFederationRequest'] = _GETFEDERATIONREQUEST
DESCRIPTOR.message_types_by_name['ListFederationsRequest'] = _LISTFEDERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListFederationsResponse'] = _LISTFEDERATIONSRESPONSE
DESCRIPTOR.message_types_by_name['CreateFederationRequest'] = _CREATEFEDERATIONREQUEST
DESCRIPTOR.message_types_by_name['CreateFederationMetadata'] = _CREATEFEDERATIONMETADATA
DESCRIPTOR.message_types_by_name['UpdateFederationRequest'] = _UPDATEFEDERATIONREQUEST
DESCRIPTOR.message_types_by_name['UpdateFederationMetadata'] = _UPDATEFEDERATIONMETADATA
DESCRIPTOR.message_types_by_name['DeleteFederationRequest'] = _DELETEFEDERATIONREQUEST
DESCRIPTOR.message_types_by_name['DeleteFederationMetadata'] = _DELETEFEDERATIONMETADATA
DESCRIPTOR.message_types_by_name['AddFederatedUserAccountsRequest'] = _ADDFEDERATEDUSERACCOUNTSREQUEST
DESCRIPTOR.message_types_by_name['AddFederatedUserAccountsMetadata'] = _ADDFEDERATEDUSERACCOUNTSMETADATA
DESCRIPTOR.message_types_by_name['AddFederatedUserAccountsResponse'] = _ADDFEDERATEDUSERACCOUNTSRESPONSE
DESCRIPTOR.message_types_by_name['ListFederatedUserAccountsRequest'] = _LISTFEDERATEDUSERACCOUNTSREQUEST
DESCRIPTOR.message_types_by_name['ListFederatedUserAccountsResponse'] = _LISTFEDERATEDUSERACCOUNTSRESPONSE
DESCRIPTOR.message_types_by_name['ListFederationOperationsRequest'] = _LISTFEDERATIONOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListFederationOperationsResponse'] = _LISTFEDERATIONOPERATIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetFederationRequest = _reflection.GeneratedProtocolMessageType('GetFederationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEDERATIONREQUEST,
  '__module__' : 'yandex.cloud.organizationmanager.v1.saml.federation_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.saml.GetFederationRequest)
  })
_sym_db.RegisterMessage(GetFederationRequest)

ListFederationsRequest = _reflection.GeneratedProtocolMessageType('ListFederationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEDERATIONSREQUEST,
  '__module__' : 'yandex.cloud.organizationmanager.v1.saml.federation_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.saml.ListFederationsRequest)
  })
_sym_db.RegisterMessage(ListFederationsRequest)

ListFederationsResponse = _reflection.GeneratedProtocolMessageType('ListFederationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEDERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.organizationmanager.v1.saml.federation_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.saml.ListFederationsResponse)
  })
_sym_db.RegisterMessage(ListFederationsResponse)

CreateFederationRequest = _reflection.GeneratedProtocolMessageType('CreateFederationRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEFEDERATIONREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.organizationmanager.v1.saml.federation_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.saml.CreateFederationRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEFEDERATIONREQUEST,
  '__module__' : 'yandex.cloud.organizationmanager.v1.saml.federation_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.saml.CreateFederationRequest)
  })
_sym_db.RegisterMessage(CreateFederationRequest)
_sym_db.RegisterMessage(CreateFederationRequest.LabelsEntry)

CreateFederationMetadata = _reflection.GeneratedProtocolMessageType('CreateFederationMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEDERATIONMETADATA,
  '__module__' : 'yandex.cloud.organizationmanager.v1.saml.federation_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.saml.CreateFederationMetadata)
  })
_sym_db.RegisterMessage(CreateFederationMetadata)

UpdateFederationRequest = _reflection.GeneratedProtocolMessageType('UpdateFederationRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATEFEDERATIONREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.organizationmanager.v1.saml.federation_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.saml.UpdateFederationRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATEFEDERATIONREQUEST,
  '__module__' : 'yandex.cloud.organizationmanager.v1.saml.federation_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.saml.UpdateFederationRequest)
  })
_sym_db.RegisterMessage(UpdateFederationRequest)
_sym_db.RegisterMessage(UpdateFederationRequest.LabelsEntry)

UpdateFederationMetadata = _reflection.GeneratedProtocolMessageType('UpdateFederationMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEDERATIONMETADATA,
  '__module__' : 'yandex.cloud.organizationmanager.v1.saml.federation_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.saml.UpdateFederationMetadata)
  })
_sym_db.RegisterMessage(UpdateFederationMetadata)

DeleteFederationRequest = _reflection.GeneratedProtocolMessageType('DeleteFederationRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEDERATIONREQUEST,
  '__module__' : 'yandex.cloud.organizationmanager.v1.saml.federation_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.saml.DeleteFederationRequest)
  })
_sym_db.RegisterMessage(DeleteFederationRequest)

DeleteFederationMetadata = _reflection.GeneratedProtocolMessageType('DeleteFederationMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEDERATIONMETADATA,
  '__module__' : 'yandex.cloud.organizationmanager.v1.saml.federation_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.saml.DeleteFederationMetadata)
  })
_sym_db.RegisterMessage(DeleteFederationMetadata)

AddFederatedUserAccountsRequest = _reflection.GeneratedProtocolMessageType('AddFederatedUserAccountsRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDFEDERATEDUSERACCOUNTSREQUEST,
  '__module__' : 'yandex.cloud.organizationmanager.v1.saml.federation_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.saml.AddFederatedUserAccountsRequest)
  })
_sym_db.RegisterMessage(AddFederatedUserAccountsRequest)

AddFederatedUserAccountsMetadata = _reflection.GeneratedProtocolMessageType('AddFederatedUserAccountsMetadata', (_message.Message,), {
  'DESCRIPTOR' : _ADDFEDERATEDUSERACCOUNTSMETADATA,
  '__module__' : 'yandex.cloud.organizationmanager.v1.saml.federation_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.saml.AddFederatedUserAccountsMetadata)
  })
_sym_db.RegisterMessage(AddFederatedUserAccountsMetadata)

AddFederatedUserAccountsResponse = _reflection.GeneratedProtocolMessageType('AddFederatedUserAccountsResponse', (_message.Message,), {
  'DESCRIPTOR' : _ADDFEDERATEDUSERACCOUNTSRESPONSE,
  '__module__' : 'yandex.cloud.organizationmanager.v1.saml.federation_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.saml.AddFederatedUserAccountsResponse)
  })
_sym_db.RegisterMessage(AddFederatedUserAccountsResponse)

ListFederatedUserAccountsRequest = _reflection.GeneratedProtocolMessageType('ListFederatedUserAccountsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEDERATEDUSERACCOUNTSREQUEST,
  '__module__' : 'yandex.cloud.organizationmanager.v1.saml.federation_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.saml.ListFederatedUserAccountsRequest)
  })
_sym_db.RegisterMessage(ListFederatedUserAccountsRequest)

ListFederatedUserAccountsResponse = _reflection.GeneratedProtocolMessageType('ListFederatedUserAccountsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEDERATEDUSERACCOUNTSRESPONSE,
  '__module__' : 'yandex.cloud.organizationmanager.v1.saml.federation_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.saml.ListFederatedUserAccountsResponse)
  })
_sym_db.RegisterMessage(ListFederatedUserAccountsResponse)

ListFederationOperationsRequest = _reflection.GeneratedProtocolMessageType('ListFederationOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEDERATIONOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.organizationmanager.v1.saml.federation_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.saml.ListFederationOperationsRequest)
  })
_sym_db.RegisterMessage(ListFederationOperationsRequest)

ListFederationOperationsResponse = _reflection.GeneratedProtocolMessageType('ListFederationOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEDERATIONOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.organizationmanager.v1.saml.federation_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.saml.ListFederationOperationsResponse)
  })
_sym_db.RegisterMessage(ListFederationOperationsResponse)


DESCRIPTOR._options = None
_GETFEDERATIONREQUEST.fields_by_name['federation_id']._options = None
_LISTFEDERATIONSREQUEST.fields_by_name['organization_id']._options = None
_LISTFEDERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTFEDERATIONSREQUEST.fields_by_name['page_token']._options = None
_LISTFEDERATIONSREQUEST.fields_by_name['filter']._options = None
_CREATEFEDERATIONREQUEST_LABELSENTRY._options = None
_CREATEFEDERATIONREQUEST.fields_by_name['organization_id']._options = None
_CREATEFEDERATIONREQUEST.fields_by_name['name']._options = None
_CREATEFEDERATIONREQUEST.fields_by_name['description']._options = None
_CREATEFEDERATIONREQUEST.fields_by_name['cookie_max_age']._options = None
_CREATEFEDERATIONREQUEST.fields_by_name['issuer']._options = None
_CREATEFEDERATIONREQUEST.fields_by_name['sso_url']._options = None
_CREATEFEDERATIONREQUEST.fields_by_name['labels']._options = None
_UPDATEFEDERATIONREQUEST_LABELSENTRY._options = None
_UPDATEFEDERATIONREQUEST.fields_by_name['federation_id']._options = None
_UPDATEFEDERATIONREQUEST.fields_by_name['name']._options = None
_UPDATEFEDERATIONREQUEST.fields_by_name['description']._options = None
_UPDATEFEDERATIONREQUEST.fields_by_name['cookie_max_age']._options = None
_UPDATEFEDERATIONREQUEST.fields_by_name['issuer']._options = None
_UPDATEFEDERATIONREQUEST.fields_by_name['sso_url']._options = None
_UPDATEFEDERATIONREQUEST.fields_by_name['labels']._options = None
_DELETEFEDERATIONREQUEST.fields_by_name['federation_id']._options = None
_ADDFEDERATEDUSERACCOUNTSREQUEST.fields_by_name['federation_id']._options = None
_ADDFEDERATEDUSERACCOUNTSREQUEST.fields_by_name['name_ids']._options = None
_LISTFEDERATEDUSERACCOUNTSREQUEST.fields_by_name['federation_id']._options = None
_LISTFEDERATEDUSERACCOUNTSREQUEST.fields_by_name['page_size']._options = None
_LISTFEDERATEDUSERACCOUNTSREQUEST.fields_by_name['page_token']._options = None
_LISTFEDERATIONOPERATIONSREQUEST.fields_by_name['federation_id']._options = None
_LISTFEDERATIONOPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTFEDERATIONOPERATIONSREQUEST.fields_by_name['page_token']._options = None

_FEDERATIONSERVICE = _descriptor.ServiceDescriptor(
  name='FederationService',
  full_name='yandex.cloud.organizationmanager.v1.saml.FederationService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=3271,
  serialized_end=5138,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.organizationmanager.v1.saml.FederationService.Get',
    index=0,
    containing_service=None,
    input_type=_GETFEDERATIONREQUEST,
    output_type=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__pb2._FEDERATION,
    serialized_options=b'\202\323\344\223\002;\0229/organization-manager/v1/saml/federations/{federation_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.organizationmanager.v1.saml.FederationService.List',
    index=1,
    containing_service=None,
    input_type=_LISTFEDERATIONSREQUEST,
    output_type=_LISTFEDERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002+\022)/organization-manager/v1/saml/federations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.organizationmanager.v1.saml.FederationService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATEFEDERATIONREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002.\")/organization-manager/v1/saml/federations:\001*\262\322*&\n\030CreateFederationMetadata\022\nFederation',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.organizationmanager.v1.saml.FederationService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATEFEDERATIONREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002>29/organization-manager/v1/saml/federations/{federation_id}:\001*\262\322*&\n\030UpdateFederationMetadata\022\nFederation',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.organizationmanager.v1.saml.FederationService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETEFEDERATIONREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002;*9/organization-manager/v1/saml/federations/{federation_id}\262\322*1\n\030DeleteFederationMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddUserAccounts',
    full_name='yandex.cloud.organizationmanager.v1.saml.FederationService.AddUserAccounts',
    index=5,
    containing_service=None,
    input_type=_ADDFEDERATEDUSERACCOUNTSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002N\"I/organization-manager/v1/saml/federations/{federation_id}:addUserAccounts:\001*\262\322*D\n AddFederatedUserAccountsMetadata\022 AddFederatedUserAccountsResponse',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListUserAccounts',
    full_name='yandex.cloud.organizationmanager.v1.saml.FederationService.ListUserAccounts',
    index=6,
    containing_service=None,
    input_type=_LISTFEDERATEDUSERACCOUNTSREQUEST,
    output_type=_LISTFEDERATEDUSERACCOUNTSRESPONSE,
    serialized_options=b'\202\323\344\223\002L\022J/organization-manager/v1/saml/federations/{federation_id}:listUserAccounts',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.organizationmanager.v1.saml.FederationService.ListOperations',
    index=7,
    containing_service=None,
    input_type=_LISTFEDERATIONOPERATIONSREQUEST,
    output_type=_LISTFEDERATIONOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002F\022D/organization-manager/v1/saml/federations/{federation_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_FEDERATIONSERVICE)

DESCRIPTOR.services_by_name['FederationService'] = _FEDERATIONSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/monitoring/v3/dashboard_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.monitoring.v3 import dashboard_pb2 as yandex_dot_cloud_dot_monitoring_dot_v3_dot_dashboard__pb2
from yandex.cloud.monitoring.v3 import parametrization_pb2 as yandex_dot_cloud_dot_monitoring_dot_v3_dot_parametrization__pb2
from yandex.cloud.monitoring.v3 import widget_pb2 as yandex_dot_cloud_dot_monitoring_dot_v3_dot_widget__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/monitoring/v3/dashboard_service.proto',
  package='yandex.cloud.monitoring.v3',
  syntax='proto3',
  serialized_options=b'\n\036yandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoring',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n2yandex/cloud/monitoring/v3/dashboard_service.proto\x12\x1ayandex.cloud.monitoring.v3\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a*yandex/cloud/monitoring/v3/dashboard.proto\x1a\x30yandex/cloud/monitoring/v3/parametrization.proto\x1a\'yandex/cloud/monitoring/v3/widget.proto\"9\n\x13GetDashboardRequest\x12\"\n\x0c\x64\x61shboard_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xa1\x01\n\x15ListDashboardsRequest\x12!\n\tfolder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50H\x00\x12\x1d\n\tpage_size\x18\x13 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x14 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x15 \x01(\tB\n\x8a\xc8\x31\x06<=1000B\x0b\n\tcontainer\"l\n\x16ListDashboardsResponse\x12\x39\n\ndashboards\x18\x01 \x03(\x0b\x32%.yandex.cloud.monitoring.v3.Dashboard\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xef\x03\n\x16\x43reateDashboardRequest\x12!\n\tfolder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50H\x00\x12\x32\n\x04name\x18\x13 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x14 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x97\x01\n\x06labels\x18\x15 \x03(\x0b\x32>.yandex.cloud.monitoring.v3.CreateDashboardRequest.LabelsEntryBG\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x16\x12\x14[a-z][-_./\\@0-9a-z]*\x12\r\n\x05title\x18\x16 \x01(\t\x12\x33\n\x07widgets\x18\x17 \x03(\x0b\x32\".yandex.cloud.monitoring.v3.Widget\x12\x44\n\x0fparametrization\x18\x18 \x01(\x0b\x32+.yandex.cloud.monitoring.v3.Parametrization\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0b\n\tcontainer\"/\n\x17\x43reateDashboardMetadata\x12\x14\n\x0c\x64\x61shboard_id\x18\x01 \x01(\t\"\xf1\x03\n\x16UpdateDashboardRequest\x12\"\n\x0c\x64\x61shboard_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\x04name\x18\x02 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x97\x01\n\x06labels\x18\x04 \x03(\x0b\x32>.yandex.cloud.monitoring.v3.UpdateDashboardRequest.LabelsEntryBG\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x16\x12\x14[a-z][-_./\\@0-9a-z]*\x12\r\n\x05title\x18\x05 \x01(\t\x12\x33\n\x07widgets\x18\x06 \x03(\x0b\x32\".yandex.cloud.monitoring.v3.Widget\x12\x44\n\x0fparametrization\x18\x07 \x01(\x0b\x32+.yandex.cloud.monitoring.v3.Parametrization\x12\x0c\n\x04\x65tag\x18\x08 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"/\n\x17UpdateDashboardMetadata\x12\x14\n\x0c\x64\x61shboard_id\x18\x01 \x01(\t\"J\n\x16\x44\x65leteDashboardRequest\x12\"\n\x0c\x64\x61shboard_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\"/\n\x17\x44\x65leteDashboardMetadata\x12\x14\n\x0c\x64\x61shboard_id\x18\x01 \x01(\t\"\x82\x01\n\x1eListDashboardOperationsRequest\x12\"\n\x0c\x64\x61shboard_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"q\n\x1fListDashboardOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xb7\x08\n\x10\x44\x61shboardService\x12\x8f\x01\n\x03Get\x12/.yandex.cloud.monitoring.v3.GetDashboardRequest\x1a%.yandex.cloud.monitoring.v3.Dashboard\"0\x82\xd3\xe4\x93\x02*\x12(/monitoring/v3/dashboards/{dashboard_id}\x12\x90\x01\n\x04List\x12\x31.yandex.cloud.monitoring.v3.ListDashboardsRequest\x1a\x32.yandex.cloud.monitoring.v3.ListDashboardsResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/monitoring/v3/dashboards\x12\xad\x01\n\x06\x43reate\x12\x32.yandex.cloud.monitoring.v3.CreateDashboardRequest\x1a!.yandex.cloud.operation.Operation\"L\x82\xd3\xe4\x93\x02\x1e\"\x19/monitoring/v3/dashboards:\x01*\xb2\xd2*$\n\x17\x43reateDashboardMetadata\x12\tDashboard\x12\xbc\x01\n\x06Update\x12\x32.yandex.cloud.monitoring.v3.UpdateDashboardRequest\x1a!.yandex.cloud.operation.Operation\"[\x82\xd3\xe4\x93\x02-2(/monitoring/v3/dashboards/{dashboard_id}:\x01*\xb2\xd2*$\n\x17UpdateDashboardMetadata\x12\tDashboard\x12\xc5\x01\n\x06\x44\x65lete\x12\x32.yandex.cloud.monitoring.v3.DeleteDashboardRequest\x1a!.yandex.cloud.operation.Operation\"d\x82\xd3\xe4\x93\x02**(/monitoring/v3/dashboards/{dashboard_id}\xb2\xd2*0\n\x17\x44\x65leteDashboardMetadata\x12\x15google.protobuf.Empty\x12\xc6\x01\n\x0eListOperations\x12:.yandex.cloud.monitoring.v3.ListDashboardOperationsRequest\x1a;.yandex.cloud.monitoring.v3.ListDashboardOperationsResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/monitoring/v3/dashboards/{dashboard_id}/operationsBk\n\x1eyandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoringb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_monitoring_dot_v3_dot_dashboard__pb2.DESCRIPTOR,yandex_dot_cloud_dot_monitoring_dot_v3_dot_parametrization__pb2.DESCRIPTOR,yandex_dot_cloud_dot_monitoring_dot_v3_dot_widget__pb2.DESCRIPTOR,])




_GETDASHBOARDREQUEST = _descriptor.Descriptor(
  name='GetDashboardRequest',
  full_name='yandex.cloud.monitoring.v3.GetDashboardRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dashboard_id', full_name='yandex.cloud.monitoring.v3.GetDashboardRequest.dashboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=352,
  serialized_end=409,
)


_LISTDASHBOARDSREQUEST = _descriptor.Descriptor(
  name='ListDashboardsRequest',
  full_name='yandex.cloud.monitoring.v3.ListDashboardsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.monitoring.v3.ListDashboardsRequest.folder_id', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.monitoring.v3.ListDashboardsRequest.page_size', index=1,
      number=19, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.monitoring.v3.ListDashboardsRequest.page_token', index=2,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.monitoring.v3.ListDashboardsRequest.filter', index=3,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='container', full_name='yandex.cloud.monitoring.v3.ListDashboardsRequest.container',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=412,
  serialized_end=573,
)


_LISTDASHBOARDSRESPONSE = _descriptor.Descriptor(
  name='ListDashboardsResponse',
  full_name='yandex.cloud.monitoring.v3.ListDashboardsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dashboards', full_name='yandex.cloud.monitoring.v3.ListDashboardsResponse.dashboards', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.monitoring.v3.ListDashboardsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=575,
  serialized_end=683,
)


_CREATEDASHBOARDREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.monitoring.v3.CreateDashboardRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.monitoring.v3.CreateDashboardRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.monitoring.v3.CreateDashboardRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1123,
  serialized_end=1168,
)

_CREATEDASHBOARDREQUEST = _descriptor.Descriptor(
  name='CreateDashboardRequest',
  full_name='yandex.cloud.monitoring.v3.CreateDashboardRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.monitoring.v3.CreateDashboardRequest.folder_id', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.monitoring.v3.CreateDashboardRequest.name', index=1,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.monitoring.v3.CreateDashboardRequest.description', index=2,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.monitoring.v3.CreateDashboardRequest.labels', index=3,
      number=21, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\017[-_./\\@0-9a-z]*\262\3101\006\032\0041-63\262\3101\026\022\024[a-z][-_./\\@0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='yandex.cloud.monitoring.v3.CreateDashboardRequest.title', index=4,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='widgets', full_name='yandex.cloud.monitoring.v3.CreateDashboardRequest.widgets', index=5,
      number=23, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parametrization', full_name='yandex.cloud.monitoring.v3.CreateDashboardRequest.parametrization', index=6,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATEDASHBOARDREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='container', full_name='yandex.cloud.monitoring.v3.CreateDashboardRequest.container',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=686,
  serialized_end=1181,
)


_CREATEDASHBOARDMETADATA = _descriptor.Descriptor(
  name='CreateDashboardMetadata',
  full_name='yandex.cloud.monitoring.v3.CreateDashboardMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dashboard_id', full_name='yandex.cloud.monitoring.v3.CreateDashboardMetadata.dashboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1183,
  serialized_end=1230,
)


_UPDATEDASHBOARDREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.monitoring.v3.UpdateDashboardRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.monitoring.v3.UpdateDashboardRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.monitoring.v3.UpdateDashboardRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1123,
  serialized_end=1168,
)

_UPDATEDASHBOARDREQUEST = _descriptor.Descriptor(
  name='UpdateDashboardRequest',
  full_name='yandex.cloud.monitoring.v3.UpdateDashboardRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dashboard_id', full_name='yandex.cloud.monitoring.v3.UpdateDashboardRequest.dashboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.monitoring.v3.UpdateDashboardRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.monitoring.v3.UpdateDashboardRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.monitoring.v3.UpdateDashboardRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\017[-_./\\@0-9a-z]*\262\3101\006\032\0041-63\262\3101\026\022\024[a-z][-_./\\@0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='yandex.cloud.monitoring.v3.UpdateDashboardRequest.title', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='widgets', full_name='yandex.cloud.monitoring.v3.UpdateDashboardRequest.widgets', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parametrization', full_name='yandex.cloud.monitoring.v3.UpdateDashboardRequest.parametrization', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='etag', full_name='yandex.cloud.monitoring.v3.UpdateDashboardRequest.etag', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATEDASHBOARDREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1233,
  serialized_end=1730,
)


_UPDATEDASHBOARDMETADATA = _descriptor.Descriptor(
  name='UpdateDashboardMetadata',
  full_name='yandex.cloud.monitoring.v3.UpdateDashboardMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dashboard_id', full_name='yandex.cloud.monitoring.v3.UpdateDashboardMetadata.dashboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1732,
  serialized_end=1779,
)


_DELETEDASHBOARDREQUEST = _descriptor.Descriptor(
  name='DeleteDashboardRequest',
  full_name='yandex.cloud.monitoring.v3.DeleteDashboardRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dashboard_id', full_name='yandex.cloud.monitoring.v3.DeleteDashboardRequest.dashboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='etag', full_name='yandex.cloud.monitoring.v3.DeleteDashboardRequest.etag', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1781,
  serialized_end=1855,
)


_DELETEDASHBOARDMETADATA = _descriptor.Descriptor(
  name='DeleteDashboardMetadata',
  full_name='yandex.cloud.monitoring.v3.DeleteDashboardMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dashboard_id', full_name='yandex.cloud.monitoring.v3.DeleteDashboardMetadata.dashboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1857,
  serialized_end=1904,
)


_LISTDASHBOARDOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListDashboardOperationsRequest',
  full_name='yandex.cloud.monitoring.v3.ListDashboardOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dashboard_id', full_name='yandex.cloud.monitoring.v3.ListDashboardOperationsRequest.dashboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.monitoring.v3.ListDashboardOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.monitoring.v3.ListDashboardOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1907,
  serialized_end=2037,
)


_LISTDASHBOARDOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListDashboardOperationsResponse',
  full_name='yandex.cloud.monitoring.v3.ListDashboardOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.monitoring.v3.ListDashboardOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.monitoring.v3.ListDashboardOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2039,
  serialized_end=2152,
)

_LISTDASHBOARDSREQUEST.oneofs_by_name['container'].fields.append(
  _LISTDASHBOARDSREQUEST.fields_by_name['folder_id'])
_LISTDASHBOARDSREQUEST.fields_by_name['folder_id'].containing_oneof = _LISTDASHBOARDSREQUEST.oneofs_by_name['container']
_LISTDASHBOARDSRESPONSE.fields_by_name['dashboards'].message_type = yandex_dot_cloud_dot_monitoring_dot_v3_dot_dashboard__pb2._DASHBOARD
_CREATEDASHBOARDREQUEST_LABELSENTRY.containing_type = _CREATEDASHBOARDREQUEST
_CREATEDASHBOARDREQUEST.fields_by_name['labels'].message_type = _CREATEDASHBOARDREQUEST_LABELSENTRY
_CREATEDASHBOARDREQUEST.fields_by_name['widgets'].message_type = yandex_dot_cloud_dot_monitoring_dot_v3_dot_widget__pb2._WIDGET
_CREATEDASHBOARDREQUEST.fields_by_name['parametrization'].message_type = yandex_dot_cloud_dot_monitoring_dot_v3_dot_parametrization__pb2._PARAMETRIZATION
_CREATEDASHBOARDREQUEST.oneofs_by_name['container'].fields.append(
  _CREATEDASHBOARDREQUEST.fields_by_name['folder_id'])
_CREATEDASHBOARDREQUEST.fields_by_name['folder_id'].containing_oneof = _CREATEDASHBOARDREQUEST.oneofs_by_name['container']
_UPDATEDASHBOARDREQUEST_LABELSENTRY.containing_type = _UPDATEDASHBOARDREQUEST
_UPDATEDASHBOARDREQUEST.fields_by_name['labels'].message_type = _UPDATEDASHBOARDREQUEST_LABELSENTRY
_UPDATEDASHBOARDREQUEST.fields_by_name['widgets'].message_type = yandex_dot_cloud_dot_monitoring_dot_v3_dot_widget__pb2._WIDGET
_UPDATEDASHBOARDREQUEST.fields_by_name['parametrization'].message_type = yandex_dot_cloud_dot_monitoring_dot_v3_dot_parametrization__pb2._PARAMETRIZATION
_LISTDASHBOARDOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['GetDashboardRequest'] = _GETDASHBOARDREQUEST
DESCRIPTOR.message_types_by_name['ListDashboardsRequest'] = _LISTDASHBOARDSREQUEST
DESCRIPTOR.message_types_by_name['ListDashboardsResponse'] = _LISTDASHBOARDSRESPONSE
DESCRIPTOR.message_types_by_name['CreateDashboardRequest'] = _CREATEDASHBOARDREQUEST
DESCRIPTOR.message_types_by_name['CreateDashboardMetadata'] = _CREATEDASHBOARDMETADATA
DESCRIPTOR.message_types_by_name['UpdateDashboardRequest'] = _UPDATEDASHBOARDREQUEST
DESCRIPTOR.message_types_by_name['UpdateDashboardMetadata'] = _UPDATEDASHBOARDMETADATA
DESCRIPTOR.message_types_by_name['DeleteDashboardRequest'] = _DELETEDASHBOARDREQUEST
DESCRIPTOR.message_types_by_name['DeleteDashboardMetadata'] = _DELETEDASHBOARDMETADATA
DESCRIPTOR.message_types_by_name['ListDashboardOperationsRequest'] = _LISTDASHBOARDOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListDashboardOperationsResponse'] = _LISTDASHBOARDOPERATIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetDashboardRequest = _reflection.GeneratedProtocolMessageType('GetDashboardRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDASHBOARDREQUEST,
  '__module__' : 'yandex.cloud.monitoring.v3.dashboard_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.GetDashboardRequest)
  })
_sym_db.RegisterMessage(GetDashboardRequest)

ListDashboardsRequest = _reflection.GeneratedProtocolMessageType('ListDashboardsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDASHBOARDSREQUEST,
  '__module__' : 'yandex.cloud.monitoring.v3.dashboard_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.ListDashboardsRequest)
  })
_sym_db.RegisterMessage(ListDashboardsRequest)

ListDashboardsResponse = _reflection.GeneratedProtocolMessageType('ListDashboardsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDASHBOARDSRESPONSE,
  '__module__' : 'yandex.cloud.monitoring.v3.dashboard_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.ListDashboardsResponse)
  })
_sym_db.RegisterMessage(ListDashboardsResponse)

CreateDashboardRequest = _reflection.GeneratedProtocolMessageType('CreateDashboardRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEDASHBOARDREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.monitoring.v3.dashboard_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.CreateDashboardRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEDASHBOARDREQUEST,
  '__module__' : 'yandex.cloud.monitoring.v3.dashboard_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.CreateDashboardRequest)
  })
_sym_db.RegisterMessage(CreateDashboardRequest)
_sym_db.RegisterMessage(CreateDashboardRequest.LabelsEntry)

CreateDashboardMetadata = _reflection.GeneratedProtocolMessageType('CreateDashboardMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDASHBOARDMETADATA,
  '__module__' : 'yandex.cloud.monitoring.v3.dashboard_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.CreateDashboardMetadata)
  })
_sym_db.RegisterMessage(CreateDashboardMetadata)

UpdateDashboardRequest = _reflection.GeneratedProtocolMessageType('UpdateDashboardRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATEDASHBOARDREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.monitoring.v3.dashboard_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.UpdateDashboardRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATEDASHBOARDREQUEST,
  '__module__' : 'yandex.cloud.monitoring.v3.dashboard_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.UpdateDashboardRequest)
  })
_sym_db.RegisterMessage(UpdateDashboardRequest)
_sym_db.RegisterMessage(UpdateDashboardRequest.LabelsEntry)

UpdateDashboardMetadata = _reflection.GeneratedProtocolMessageType('UpdateDashboardMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDASHBOARDMETADATA,
  '__module__' : 'yandex.cloud.monitoring.v3.dashboard_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.UpdateDashboardMetadata)
  })
_sym_db.RegisterMessage(UpdateDashboardMetadata)

DeleteDashboardRequest = _reflection.GeneratedProtocolMessageType('DeleteDashboardRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDASHBOARDREQUEST,
  '__module__' : 'yandex.cloud.monitoring.v3.dashboard_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.DeleteDashboardRequest)
  })
_sym_db.RegisterMessage(DeleteDashboardRequest)

DeleteDashboardMetadata = _reflection.GeneratedProtocolMessageType('DeleteDashboardMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDASHBOARDMETADATA,
  '__module__' : 'yandex.cloud.monitoring.v3.dashboard_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.DeleteDashboardMetadata)
  })
_sym_db.RegisterMessage(DeleteDashboardMetadata)

ListDashboardOperationsRequest = _reflection.GeneratedProtocolMessageType('ListDashboardOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDASHBOARDOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.monitoring.v3.dashboard_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.ListDashboardOperationsRequest)
  })
_sym_db.RegisterMessage(ListDashboardOperationsRequest)

ListDashboardOperationsResponse = _reflection.GeneratedProtocolMessageType('ListDashboardOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDASHBOARDOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.monitoring.v3.dashboard_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.ListDashboardOperationsResponse)
  })
_sym_db.RegisterMessage(ListDashboardOperationsResponse)


DESCRIPTOR._options = None
_GETDASHBOARDREQUEST.fields_by_name['dashboard_id']._options = None
_LISTDASHBOARDSREQUEST.fields_by_name['folder_id']._options = None
_LISTDASHBOARDSREQUEST.fields_by_name['page_size']._options = None
_LISTDASHBOARDSREQUEST.fields_by_name['page_token']._options = None
_LISTDASHBOARDSREQUEST.fields_by_name['filter']._options = None
_CREATEDASHBOARDREQUEST_LABELSENTRY._options = None
_CREATEDASHBOARDREQUEST.fields_by_name['folder_id']._options = None
_CREATEDASHBOARDREQUEST.fields_by_name['name']._options = None
_CREATEDASHBOARDREQUEST.fields_by_name['description']._options = None
_CREATEDASHBOARDREQUEST.fields_by_name['labels']._options = None
_UPDATEDASHBOARDREQUEST_LABELSENTRY._options = None
_UPDATEDASHBOARDREQUEST.fields_by_name['dashboard_id']._options = None
_UPDATEDASHBOARDREQUEST.fields_by_name['name']._options = None
_UPDATEDASHBOARDREQUEST.fields_by_name['description']._options = None
_UPDATEDASHBOARDREQUEST.fields_by_name['labels']._options = None
_DELETEDASHBOARDREQUEST.fields_by_name['dashboard_id']._options = None
_LISTDASHBOARDOPERATIONSREQUEST.fields_by_name['dashboard_id']._options = None
_LISTDASHBOARDOPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTDASHBOARDOPERATIONSREQUEST.fields_by_name['page_token']._options = None

_DASHBOARDSERVICE = _descriptor.ServiceDescriptor(
  name='DashboardService',
  full_name='yandex.cloud.monitoring.v3.DashboardService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2155,
  serialized_end=3234,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.monitoring.v3.DashboardService.Get',
    index=0,
    containing_service=None,
    input_type=_GETDASHBOARDREQUEST,
    output_type=yandex_dot_cloud_dot_monitoring_dot_v3_dot_dashboard__pb2._DASHBOARD,
    serialized_options=b'\202\323\344\223\002*\022(/monitoring/v3/dashboards/{dashboard_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.monitoring.v3.DashboardService.List',
    index=1,
    containing_service=None,
    input_type=_LISTDASHBOARDSREQUEST,
    output_type=_LISTDASHBOARDSRESPONSE,
    serialized_options=b'\202\323\344\223\002\033\022\031/monitoring/v3/dashboards',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.monitoring.v3.DashboardService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATEDASHBOARDREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\036\"\031/monitoring/v3/dashboards:\001*\262\322*$\n\027CreateDashboardMetadata\022\tDashboard',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.monitoring.v3.DashboardService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATEDASHBOARDREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002-2(/monitoring/v3/dashboards/{dashboard_id}:\001*\262\322*$\n\027UpdateDashboardMetadata\022\tDashboard',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.monitoring.v3.DashboardService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETEDASHBOARDREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002**(/monitoring/v3/dashboards/{dashboard_id}\262\322*0\n\027DeleteDashboardMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.monitoring.v3.DashboardService.ListOperations',
    index=5,
    containing_service=None,
    input_type=_LISTDASHBOARDOPERATIONSREQUEST,
    output_type=_LISTDASHBOARDOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\0025\0223/monitoring/v3/dashboards/{dashboard_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DASHBOARDSERVICE)

DESCRIPTOR.services_by_name['DashboardService'] = _DASHBOARDSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/vision/v1/classification.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/ai/vision/v1/classification.proto',
  package='yandex.cloud.ai.vision.v1',
  syntax='proto3',
  serialized_options=b'\n\035yandex.cloud.api.ai.vision.v1ZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/vision/v1;vision',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.yandex/cloud/ai/vision/v1/classification.proto\x12\x19yandex.cloud.ai.vision.v1\"J\n\x0f\x43lassAnnotation\x12\x37\n\nproperties\x18\x01 \x03(\x0b\x32#.yandex.cloud.ai.vision.v1.Property\"-\n\x08Property\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0bprobability\x18\x02 \x01(\x01\x42\x65\n\x1dyandex.cloud.api.ai.vision.v1ZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/vision/v1;visionb\x06proto3'
)




_CLASSANNOTATION = _descriptor.Descriptor(
  name='ClassAnnotation',
  full_name='yandex.cloud.ai.vision.v1.ClassAnnotation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='properties', full_name='yandex.cloud.ai.vision.v1.ClassAnnotation.properties', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=77,
  serialized_end=151,
)


_PROPERTY = _descriptor.Descriptor(
  name='Property',
  full_name='yandex.cloud.ai.vision.v1.Property',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.ai.vision.v1.Property.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='probability', full_name='yandex.cloud.ai.vision.v1.Property.probability', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=153,
  serialized_end=198,
)

_CLASSANNOTATION.fields_by_name['properties'].message_type = _PROPERTY
DESCRIPTOR.message_types_by_name['ClassAnnotation'] = _CLASSANNOTATION
DESCRIPTOR.message_types_by_name['Property'] = _PROPERTY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClassAnnotation = _reflection.GeneratedProtocolMessageType('ClassAnnotation', (_message.Message,), {
  'DESCRIPTOR' : _CLASSANNOTATION,
  '__module__' : 'yandex.cloud.ai.vision.v1.classification_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ai.vision.v1.ClassAnnotation)
  })
_sym_db.RegisterMessage(ClassAnnotation)

Property = _reflection.GeneratedProtocolMessageType('Property', (_message.Message,), {
  'DESCRIPTOR' : _PROPERTY,
  '__module__' : 'yandex.cloud.ai.vision.v1.classification_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ai.vision.v1.Property)
  })
_sym_db.RegisterMessage(Property)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
